km3pipe\.tools\.deprecated
==========================

.. currentmodule:: km3pipe.tools

.. autoclass:: deprecated

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~deprecated.__init__
   
   

   
   
   